@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -27,7 +27,7 @@
  * <refsect2>
  * <title>Example launch line</title>
  * |[
- * gst-launch filesrc location=abc.amr ! amrparse ! amrnbdec ! audioresample ! audioconvert ! alsasink
+ * gst-launch-1.0 filesrc location=abc.amr ! amrparse ! amrnbdec ! audioconvert ! audioresample ! autoaudiosink
  * ]|
  * </refsect2>
  */
@@ -96,8 +96,8 @@ static void gst_amrnbdec_get_property (GObject * object, guint prop_id,
 static gboolean gst_amrnbdec_start (GstAudioDecoder * dec);
 static gboolean gst_amrnbdec_stop (GstAudioDecoder * dec);
 static gboolean gst_amrnbdec_set_format (GstAudioDecoder * dec, GstCaps * caps);
-static gboolean gst_amrnbdec_parse (GstAudioDecoder * dec, GstAdapter * adapter,
-    gint * offset, gint * length);
+static GstFlowReturn gst_amrnbdec_parse (GstAudioDecoder * dec,
+    GstAdapter * adapter, gint * offset, gint * length);
 static GstFlowReturn gst_amrnbdec_handle_frame (GstAudioDecoder * dec,
     GstBuffer * buffer);
 
@@ -114,15 +114,13 @@ gst_amrnbdec_class_init (GstAmrnbDecClass * klass)
   object_class->set_property = gst_amrnbdec_set_property;
   object_class->get_property = gst_amrnbdec_get_property;
 
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&sink_template));
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&src_template));
+  gst_element_class_add_static_pad_template (element_class, &sink_template);
+  gst_element_class_add_static_pad_template (element_class, &src_template);
 
   gst_element_class_set_static_metadata (element_class, "AMR-NB audio decoder",
       "Codec/Decoder/Audio",
       "Adaptive Multi-Rate Narrow-Band audio decoder",
-      "GStreamer maintainers <gstreamer-devel@lists.sourceforge.net>");
+      "GStreamer maintainers <gstreamer-devel@lists.freedesktop.org>");
 
   base_class->start = GST_DEBUG_FUNCPTR (gst_amrnbdec_start);
   base_class->stop = GST_DEBUG_FUNCPTR (gst_amrnbdec_stop);
@@ -143,6 +141,10 @@ gst_amrnbdec_class_init (GstAmrnbDecClass * klass)
 static void
 gst_amrnbdec_init (GstAmrnbDec * amrnbdec)
 {
+  gst_audio_decoder_set_needs_format (GST_AUDIO_DECODER (amrnbdec), TRUE);
+  gst_audio_decoder_set_use_default_pad_acceptcaps (GST_AUDIO_DECODER_CAST
+      (amrnbdec), TRUE);
+  GST_PAD_SET_ACCEPT_TEMPLATE (GST_AUDIO_DECODER_SINK_PAD (amrnbdec));
 }
 
 static gboolean
@@ -289,9 +291,6 @@ gst_amrnbdec_handle_frame (GstAudioDecoder * dec, GstBuffer * buffer)
   if (!buffer || !gst_buffer_get_size (buffer))
     return GST_FLOW_OK;
 
-  if (amrnbdec->rate == 0 || amrnbdec->channels == 0)
-    goto not_negotiated;
-
   gst_buffer_map (buffer, &inmap, GST_MAP_READ);
 
   /* get output */
@@ -305,12 +304,4 @@ gst_amrnbdec_handle_frame (GstAudioDecoder * dec, GstBuffer * buffer)
   gst_buffer_unmap (buffer, &inmap);
 
   return gst_audio_decoder_finish_frame (dec, out, 1);
-
-  /* ERRORS */
-not_negotiated:
-  {
-    GST_ELEMENT_ERROR (amrnbdec, STREAM, TYPE_NOT_FOUND, (NULL),
-        ("Decoder is not initialized"));
-    return GST_FLOW_NOT_NEGOTIATED;
-  }
 }
